@@ -14,10 +14,10 @@ sub UNITCHECK {				## restore %SIG after compilation
 package Net::DNS::RR::SIG;
 
 #
-# $Id: SIG.pm 1352 2015-06-02 08:13:13Z willem $
+# $Id: SIG.pm 1362 2015-06-23 08:47:14Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1352 $)[1];
+$VERSION = (qw$LastChangedRevision: 1362 $)[1];
 
 
 use strict;
@@ -158,12 +158,12 @@ sub defaults() {			## specify RR attribute default values
 		my $name = shift;
 		my $key	 = uc $name;				# synthetic key
 		$key =~ s/[^A-Z0-9]//g;				# strip non-alphanumerics
-		return $algbyname{$key} || croak "unknown algorithm $name";
+		$algbyname{$key} || croak "unknown algorithm $name";
 	}
 
 	sub algbyval {
 		my $value = shift;
-		return $algbyval{$value} || $value;
+		$algbyval{$value} || return $value;
 	}
 }
 
@@ -233,7 +233,7 @@ sub keytag {
 	my $self = shift;
 
 	$self->{keytag} = 0 + shift if scalar @_;
-	return $self->{keytag} || 0;
+	$self->{keytag} || 0;
 }
 
 
