@@ -1,10 +1,10 @@
 package Net::DNS::Update;
 
 #
-# $Id: Update.pm 1348 2015-05-27 09:55:13Z willem $
+# $Id: Update.pm 1359 2015-06-11 17:21:03Z willem $
 #
 use vars qw($VERSION @ISA);
-$VERSION = (qw$LastChangedRevision: 1348 $)[1];
+$VERSION = (qw$LastChangedRevision: 1359 $)[1];
 
 
 =head1 NAME
@@ -33,6 +33,8 @@ Programmers should refer to RFC2136 for dynamic update semantics.
 use strict;
 use base 'Net::DNS::Packet';
 
+use Carp;
+
 
 =head1 METHODS
 
@@ -57,25 +59,26 @@ If the class is omitted, it defaults to IN.
 =cut
 
 sub new {
-	my $package = shift;
-	my ( $zone, $class ) = @_;
+	shift;
+	my ( $zone, @class ) = @_;
 
-	unless ($zone) {
+	unless ( scalar @_ ) {
 		require Net::DNS::Resolver;
-		my $resolver = new Net::DNS::Resolver();	# create resolver object
+		my $resolver = new Net::DNS::Resolver();
 
-		($zone) = $resolver->searchlist;
-		return unless $zone;
+		($zone) = $resolver->searchlist;		# default from resolver config
 	}
 
-	return $package->SUPER::decode(@_) if ref($zone);
+	eval {
+		my $self = __PACKAGE__->SUPER::new( $zone, 'SOA', @class );
 
-	my $self = $package->SUPER::new( $zone, 'SOA', $class ) || return;
+		my $header = $self->header;
+		$header->opcode('UPDATE');
+		$header->qr(0);
+		$header->rd(0);
 
-	$self->header->opcode('UPDATE');
-	$self->header->rd(0);
-
-	return $self;
+		return $self;
+	} || croak $@;
 }
 
 
